==> nextcloud-app-contacts-5.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/es_419.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalles",
    "All contacts" : "Todos los contactos",
    "Contacts" : "Contactos",
    "Loading contacts …" : "Cargando contactos ...",
    "Delete circle" : "Borrar círculo",
    "General settings" : "Configuraciones generales",
    "Send email" : "Enviar correo electrónico",
    "Circles" : "Círculos",
    "Create a new circle" : "Crear un nuevo círculo",
    "Download" : "Descargar",
    "Rename" : "Renombrar",
    "Delete" : "Borrar",
    "Copy link" : "Copiar liga",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "First name" : "Nombre",
    "Last name" : "Apellido",
    "Display name" : "Nombre a desplegar",
    "Last modified" : "Última modificación",
    "Password protection" : "Protección con contraseña",
    "Save" : "Guardar",
    "Description" : "Descripción",
    "Cancel" : "Cancelar",
    "Invalid image" : "Imagen inválida",
    "Name" : "Nombre",
    "Title" : "Título",
    "Address book" : "Libreta de direcciones",
    "Search contacts …" : "Buscar contactos ...",
    "No results" : "No hay resultados",
    "Personal circle" : "Círculo personal",
    "Pending" : "Pendiente",
    "New contact" : "Nuevo contacto",
    "Close" : "Cerrar",
    "Import" : "Importar",
    "Not grouped" : "No agrupado",
    "Circle" : "Círculo",
    "User" : "Ususario",
    "Group" : "Grupo",
    "Email" : "Correo electrónico",
    "Contact" : "Contacto",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administración",
    "Owner" : "Dueño",
    "Users" : "Ususarios",
    "Detailed name" : "Nombre detallado",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Nickname" : "Apodo",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Location" : "Ubicación",
    "Federated Cloud ID" : "Id de nube federada",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Address" : "Dirección",
    "Post office box" : "Apartado postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de defunción",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono fijo",
    "Mobile" : "Teléfono móvil",
    "Work mobile" : "Número celular de trabajo",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Auto",
    "Work pager" : "Localizador de trabajo",
    "Manager" : "Gerente",
    "Social network" : "Red social",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Padre",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Familiar",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Asistente",
    "Gender" : "Género",
    "Female" : "Femenino",
    "Male" : "Masculino",
    "None" : "Ninguno",
    "Unknown" : "Desconocido"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-contacts-7.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/es_419.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalles",
    "All contacts" : "Todos los contactos",
    "Contacts" : "Contactos",
    "Loading contacts …" : "Cargando contactos ...",
    "General settings" : "Configuraciones generales",
    "Rename" : "Renombrar",
    "Send email" : "Enviar correo electrónico",
    "Delete" : "Borrar",
    "Download" : "Descargar",
    "Copy link" : "Copiar liga",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "Add" : "Agregar",
    "First name" : "Nombre",
    "Last name" : "Apellido",
    "Display name" : "Nombre a desplegar",
    "Last modified" : "Última modificación",
    "Password protection" : "Protección con contraseña",
    "Save" : "Guardar",
    "Description" : "Descripción",
    "Settings" : "Settings",
    "Cancel" : "Cancelar",
    "Invalid image" : "Imagen inválida",
    "Name" : "Nombre",
    "Title" : "Título",
    "Address book" : "Libreta de direcciones",
    "Search contacts …" : "Buscar contactos ...",
    "No results" : "No hay resultados",
    "Pending" : "Pendiente",
    "None" : "Ninguno",
    "New contact" : "Nuevo contacto",
    "Close" : "Cerrar",
    "Import" : "Importar",
    "Not grouped" : "No agrupado",
    "User" : "Ususario",
    "Group" : "Grupo",
    "Email" : "Correo electrónico",
    "Contact" : "Contacto",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administración",
    "Owner" : "Dueño",
    "Groups" : "Grupos",
    "Detailed name" : "Nombre detallado",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Nickname" : "Apodo",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Location" : "Ubicación",
    "Federated Cloud ID" : "Id de nube federada",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Address" : "Dirección",
    "Post office box" : "Apartado postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de defunción",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono fijo",
    "Mobile" : "Teléfono móvil",
    "Work mobile" : "Número celular de trabajo",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Auto",
    "Work pager" : "Localizador de trabajo",
    "Social network" : "Red social",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Padre",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Familiar",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Asistente",
    "Gender" : "Género",
    "Female" : "Femenino",
    "Male" : "Masculino",
    "Unknown" : "Desconocido",
    "Manager" : "Gerente"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
